@@ -102,7 +102,9 @@ for(i in 1:NrRef) {
 
 val <- hglm.default(X = X, y = Y, Z = Z, family = family, rand.family = rand.family, X.disp = x.disp,
                     link.disp = link.disp, method = method, conv = conv, maxit = maxit, startval = startval,
-                    weights = weights, fix.disp = fix.disp, offset = offset, RandC = nRand, sparse = sparse, vcovmat = vcovmat, ...)
+                    weights = weights, fix.disp = fix.disp, offset = offset, sparse = sparse, 
+					vcovmat = vcovmat, calc.like = calc.like, bigRR = bigRR, verbose = verbose, ...)
+			
 val$call <- Call
 
 return(val)
